@@ -8,8 +8,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/bin',
- 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6',
+ 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/bin',
+ 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7',
  'BLDLIBRARY': '',
  'BLDSHARED': '/opt/local/bin/clang-mp-11 -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'BUILDEXE': '',
@@ -24,28 +24,28 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-pipe -I/opt/local/libexec/openssl11/include -Os ',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes',
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-I/opt/local/libexec/openssl11/include -isystem/opt/local/include',
  'CONFIGURE_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' '--with-ensurepip=no' '--with-system-expat' '--with-system-ffi' 'CC=/opt/local/bin/clang-mp-11' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os ' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl11/lib/pkgconfig'",
- 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/include',
- 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/include/python3.6m',
- 'COREPYTHONPATH': ':',
- 'COVERAGE_INFO': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15/coverage.info',
- 'COVERAGE_REPORT': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15/lcov-report',
+ 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/include',
+ 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/include/python3.7m',
+ 'COREPYTHONPATH': '',
+ 'COVERAGE_INFO': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17/coverage.info',
+ 'COVERAGE_REPORT': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include',
  'CXX': '/opt/local/bin/clang++-mp-11',
- 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6 /opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6 /opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6/lib-dynload',
- 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6',
+ 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7 /opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7 /opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7/lib-dynload',
+ 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6/lib-dynload',
+ 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
  'DISTDIRS': 'Include Lib Misc Ext-dummy',
- 'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
+ 'DISTFILES': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
@@ -60,10 +60,9 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
- 'EXT_SUFFIX': '.cpython-36m-darwin.so',
+ 'EXT_SUFFIX': '.cpython-37m-darwin.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
@@ -106,6 +105,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 0,
+ 'HAVE_CRYPT_R': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 1,
  'HAVE_CURSES_FILTER': 1,
@@ -127,6 +127,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DECL_RTLD_GLOBAL': 1,
  'HAVE_DECL_RTLD_LAZY': 1,
  'HAVE_DECL_RTLD_LOCAL': 1,
+ 'HAVE_DECL_RTLD_MEMBER': 0,
  'HAVE_DECL_RTLD_NODELETE': 1,
  'HAVE_DECL_RTLD_NOLOAD': 1,
  'HAVE_DECL_RTLD_NOW': 1,
@@ -142,6 +143,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DUP3': 0,
+ 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_ENDIAN_H': 0,
  'HAVE_EPOLL': 0,
@@ -253,6 +255,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LINUX_VM_SOCKETS_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -261,7 +264,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 0,
  'HAVE_MKDIRAT': 0,
@@ -287,12 +289,15 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_POLL_H': 0,
  'HAVE_POSIX_FADVISE': 0,
  'HAVE_POSIX_FALLOCATE': 0,
+ 'HAVE_POSIX_SPAWN': 1,
  'HAVE_PREAD': 1,
+ 'HAVE_PREADV': 0,
+ 'HAVE_PREADV2': 0,
  'HAVE_PRLIMIT': 0,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
+ 'HAVE_PTHREAD_GETCPUCLOCKID': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
  'HAVE_PTHREAD_KILL': 1,
@@ -300,13 +305,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
+ 'HAVE_PWRITEV': 0,
+ 'HAVE_PWRITEV2': 0,
  'HAVE_READLINK': 1,
  'HAVE_READLINKAT': 0,
  'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RENAMEAT': 0,
  'HAVE_RL_APPEND_HISTORY': 1,
- 'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
@@ -321,7 +327,6 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SCHED_SETAFFINITY': 0,
  'HAVE_SCHED_SETPARAM': 0,
  'HAVE_SCHED_SETSCHEDULER': 0,
- 'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 0,
@@ -347,6 +352,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGALTSTACK': 1,
+ 'HAVE_SIGINFO_T_SI_BAND': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
  'HAVE_SIGPENDING': 1,
@@ -448,6 +454,11 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_UTIMENSAT': 0,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
+ 'HAVE_UUID_CREATE': 0,
+ 'HAVE_UUID_ENC_BE': 0,
+ 'HAVE_UUID_GENERATE_TIME_SAFE': 0,
+ 'HAVE_UUID_H': 0,
+ 'HAVE_UUID_UUID_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
  'HAVE_WAITID': 1,
@@ -459,44 +470,45 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_WMEMCMP': 1,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_WRITEV': 1,
+ 'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
  'HOST_GNU_TYPE': 'i386-apple-darwin10.8.0',
- 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/include /opt/local/Library/Frameworks/Python.framework/Versions/3.6/include /opt/local/Library/Frameworks/Python.framework/Versions/3.6/include/python3.6m /opt/local/Library/Frameworks/Python.framework/Versions/3.6/include/python3.6m',
- 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/include',
- 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/include/python3.6m',
+ 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/include /opt/local/Library/Frameworks/Python.framework/Versions/3.7/include /opt/local/Library/Frameworks/Python.framework/Versions/3.7/include/python3.7m /opt/local/Library/Frameworks/Python.framework/Versions/3.7/include/python3.7m',
+ 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/include',
+ 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/include/python3.7m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'Python.framework/Versions/3.6/Python',
+ 'INSTSONAME': 'Python.framework/Versions/3.7/Python',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': '/opt/local/bin/clang++-mp-11 -bundle -undefined dynamic_lookup',
  'LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
- 'LDLIBRARY': 'Python.framework/Versions/3.6/Python',
+ 'LDLIBRARY': 'Python.framework/Versions/3.7/Python',
  'LDLIBRARYDIR': '',
  'LDSHARED': '/opt/local/bin/clang-mp-11 -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
- 'LDVERSION': '3.6m',
+ 'LDVERSION': '3.7m',
  'LIBC': '',
- 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6',
- 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib',
+ 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7',
+ 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib',
  'LIBFFI_INCLUDEDIR': '/opt/local/include',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/pkgconfig',
- 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6/config-3.6m-darwin',
- 'LIBRARY': 'libpython3.6m.a',
+ 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/pkgconfig',
+ 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7/config-3.7m-darwin',
+ 'LIBRARY': 'libpython3.7m.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': ' -ldl  -framework CoreFoundation',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': '/opt/local/bin/clang-mp-11',
- 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6/config-3.6m-darwin -lpython3.6m -ldl -framework CoreFoundation',
+ 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7/config-3.7m-darwin -lpython3.7m -ldl -framework CoreFoundation',
  'LIPO_32BIT_FLAGS': '',
  'LLVM_PROF_ERR': 'yes',
  'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
@@ -505,25 +517,28 @@ build_time_vars = {'ABIFLAGS': 'm',
  'LOCALMODLIBS': '',
  'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'darwin',
- 'MACHDEPPATH': ':',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib/python3.6',
+ 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib/python3.7',
  'MACOSX_DEPLOYMENT_TARGET': '10.6',
  'MAINCC': '/opt/local/bin/clang-mp-11',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/share/man',
+ 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/share/man',
  'MKDIR_P': './install-sh -c -d',
+ 'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  _operator  _collections  _abc  itertools  atexit  _signal  _stat  time  _thread  _locale  _io  zipimport  faulthandler  _tracemalloc  _symtable  xxsubtype',
+ 'MODDISABLED_NAMES': '',
  'MODLIBS': '',
- 'MODNAMES': '_thread posix errno pwd _sre _codecs _weakref _functools _operator _collections itertools atexit _signal _stat time _locale _io zipimport faulthandler _tracemalloc _symtable xxsubtype',
- 'MODOBJS': 'Modules/_threadmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  Modules/timemodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/_tracemalloc.o Modules/hashtable.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/_operator.o  Modules/_collectionsmodule.o  Modules/_abc.o  Modules/itertoolsmodule.o  Modules/atexitmodule.o  Modules/signalmodule.o  Modules/_stat.o  Modules/timemodule.o  Modules/_threadmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/_tracemalloc.o Modules/hashtable.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': 'darwin',
  'MULTIARCH_CPPFLAGS': '-DMULTIARCH=\\"darwin\\"',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '',
  'OBJECT_OBJS': '\\',
+ 'OPENSSL_INCLUDES': '-I/opt/local/libexec/openssl11/include',
+ 'OPENSSL_LDFLAGS': '-L/opt/local/libexec/openssl11/lib',
+ 'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -539,10 +554,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
- 'PLATDIR': '',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo',
+ 'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
  'PY3LIBRARY': '',
@@ -552,19 +567,24 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHONFRAMEWORKDIR': 'Python.framework',
  'PYTHONFRAMEWORKINSTALLDIR': '/opt/local/Library/Frameworks/Python.framework',
  'PYTHONFRAMEWORKPREFIX': '/opt/local/Library/Frameworks',
- 'PYTHONPATH': ':',
+ 'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
  'PYTHON_FOR_REGEN': 'python',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -pipe -I/opt/local/libexec/openssl11/include -Os  -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -I. -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -pipe -I/opt/local/libexec/openssl11/include -Os ',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes',
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -pipe -I/opt/local/libexec/openssl11/include -Os  -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -I. -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include  -DPy_BUILD_CORE',
+ 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration',
+ 'PY_COERCE_C_LOCALE': 1,
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -pipe -I/opt/local/libexec/openssl11/include -Os  -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -I. -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'PY_CPPFLAGS': '-I. -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'PY_LDFLAGS_NODIST': '',
+ 'PY_SSL_DEFAULT_CIPHERS': 1,
+ 'PY_SSL_DEFAULT_CIPHER_STRING': 0,
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -pipe -I/opt/local/libexec/openssl11/include -Os  -std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter -Wno-missing-field-initializers -Wstrict-prototypes -Werror=implicit-function-declaration -I. -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
  'Py_HASH_ALGORITHM': 0,
@@ -572,10 +592,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15',
- 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/lib',
+ 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17',
+ 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/lib',
  'SETPGRP_HAVE_ARG': 0,
- 'SGI_ABI': '',
+ 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': ' -ldl  -framework CoreFoundation',
  'SHLIB_SUFFIX': '.so',
@@ -590,6 +610,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
+ 'SIZEOF_PTHREAD_KEY_T': 4,
  'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
  'SIZEOF_SIZE_T': 4,
@@ -598,8 +619,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-36m-darwin',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
+ 'SOABI': 'cpython-37m-darwin',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -613,11 +634,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15 ./python',
+ 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15 ./python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17 ./python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
- 'THREADOBJ': 'Python/thread.o',
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
@@ -625,23 +645,21 @@ build_time_vars = {'ABIFLAGS': 'm',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
- 'USE_INLINE': 1,
- 'VERSION': '3.6',
- 'WANT_SIGFPE_HANDLER': 0,
+ 'VERSION': '3.7',
  'WINDOW_HAS_FLAGS': 1,
+ 'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 0,
  'WITH_DYLD': 1,
  'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 1,
  'WITH_PYMALLOC': 1,
- 'WITH_THREAD': 1,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15',
- 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python36/python36/work/Python-3.6.15',
- 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6/share',
- 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6',
- 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.6',
+ 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17',
+ 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python37/python37/work/Python-3.7.17',
+ 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7/share',
+ 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7',
+ 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.7',
  'srcdir': '.'}
